#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ROL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ROL_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/scalar/rol.hpp>

#endif
